from distutils.core import setup

setup(
    name = 'kprintdiamond',      
    version = '1.0.0',
    py_modules = ['kprint01'],
    author = 'kingon01',        
    author_email = '1047200331@qq.com',
    url = 'https://upload.pypi.org/legacy/',
    description = '打印功能展示'   
    )